# UpstreamGroupExcludedEntry

The mapping between an upsteam group and a group in the Agilicus System
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**upstream_group_name** | **str** | The name of the group in your upstream identity provider that you want to map. This can be in the form of a regular expression.  | 
**upstream_name_is_a_guid** | **bool** | Indicates that the supplied upstream_group_name will be found in the list of group IDs | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


